@@ -95,6 +95,18 @@ class ProjectWidget(QtWidgets.QWidget):
             )
         )
 
+        # MY TASKS
+        self.tasks_button = ProjectThumbnailWidget(
+            128, 32,  alt_text="My Tasks"
+        )
+
+        self.tasks_button.clicked.connect(
+            lambda project=project, button="tasks": self.on_project_button_clicked(
+                project, button
+            )
+        )
+
+
         # FAVORITE
         custom_home_star_path = os.path.join(
             os.path.dirname(resources.icons.libreflow.__file__), "custom_home_star.png"
@@ -135,10 +147,11 @@ class ProjectWidget(QtWidgets.QWidget):
             )
         )
 
-        self.grid_layout.addWidget(self.thumbnail_button, 0, 0, 3, 1)
-        self.grid_layout.addWidget(self.fav_button, 0, 1)
-        self.grid_layout.addWidget(self.sequences_button, 1, 1)
-        self.grid_layout.addWidget(self.assets_button, 2, 1)
+        self.grid_layout.addWidget(self.thumbnail_button, 0, 0, 4, 1)
+        self.grid_layout.addWidget(self.tasks_button, 0, 1)
+        self.grid_layout.addWidget(self.fav_button, 1, 1)
+        self.grid_layout.addWidget(self.sequences_button, 2, 1)
+        self.grid_layout.addWidget(self.assets_button, 3, 1)
 
         try:
             requiered_versions = self.HomePageWidget.session.cmds.Flow.call(
@@ -178,6 +191,8 @@ class ProjectWidget(QtWidgets.QWidget):
     def on_project_button_clicked(self, project, button):
         if button == "thumbnail":
             oid = "/%s" % project
+        elif button == "tasks":
+            oid = "/%s/mytasks" % project
         elif button == "fav":
             oid = "/%s/user" % project
         elif button == "seq":
