@@ -39,7 +39,7 @@ class CreateKitsuAssets(flow.Action):
 
     skip_existing = flow.SessionParam(False).ui(editor='bool')
 
-    _asset_types = flow.Parent(4)
+    _asset_type = flow.Parent(2)
     _assets = flow.Parent()
 
     def get_buttons(self):
@@ -50,7 +50,7 @@ class CreateKitsuAssets(flow.Action):
             return
         
         skip_existing = self.skip_existing.get()
-        assets_data = self.root().project().kitsu_api().get_assets_data(self._asset_types.name())
+        assets_data = self.root().project().kitsu_api().get_assets_data(self._asset_type.name())
         for data in assets_data:
             name = data['name'].lower()
 
@@ -61,7 +61,7 @@ class CreateKitsuAssets(flow.Action):
             else:
                 continue
             
-            print(f'Create asset {self._asset_types.name()} {data["name"]}')
+            print(f'Create asset: {self._asset_type.name()} - {data["name"]}')
         
         self._assets.touch()
 
@@ -140,18 +140,16 @@ class CreateKitsuAssetTypes(flow.Action):
 
             if not self._asset_types.has_mapped_name(name):
                 a = self._asset_types.add(name)
-                a.asset_families.add('main')
             elif not skip_existing:
                 a = self._asset_types[name]
             else:
                 continue
             
-            print(f'Create asset type {data["name"]}')
+            print(f'Create asset type: {data["name"]}')
 
             if create_assets:
-                if a.asset_families.has_mapped_name('main'):
-                    a.asset_families['main'].create_assets.skip_existing.set(skip_existing)
-                    a.asset_families['main'].create_assets.run('Create assets')
+                a.assets.create_assets.skip_existing.set(skip_existing)
+                a.assets.create_assets.run('Create assets')
         
         self._asset_types.touch()
 
