@@ -43,10 +43,16 @@ if CUSTOM_HOME:
     from .custom_home import MyHomeRoot
 
 from .resources import file_templates
-from .resources.gui.styles.default_style import DefaultStyle
 
 
-DefaultStyle()
+try:
+    from libreflow.resources.styles.lfs_tech import LfsTechStyle  
+except ImportError:
+    from .resources.gui.styles.default_style import DefaultStyle
+    DefaultStyle()
+else:
+    LfsTechStyle()
+
 
 
 class SessionGUI(gui.KabaretStandaloneGUISession):
